searchData={"items":[{"type":"module","title":"ExAws.S3.Crypto","doc":"`ExAws.S3.Crypto` provides [client-side encryption](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingClientSideEncryption.html) support for\n[Amazon S3](https://aws.amazon.com/s3/).  It allows you to encrypt data before sending it to S3.  This particular implementation\ncurrently supports a [AWS KMS-managed customer master key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys)\nand assumes you have one already generated.\n\nThis library makes heavy use of the existing [ex_aws_s3](https://hex.pm/packages/ex_aws_s3) library\nand Erlang's [crypto module](http://erlang.org/doc/man/crypto.html).  It has confirmed compatability with the [Golang AWS SDK client-encryption\nlibrary](https://github.com/aws/aws-sdk-go/tree/master/service/s3) and uses [AES](https://en.wikipedia.org/wiki/Advanced_Encryption_Standard)\n[GCM](https://en.wikipedia.org/wiki/Galois/Counter_Mode) with 256-bit keys by default.","ref":"ExAws.S3.Crypto.html"},{"type":"module","title":"Examples - ExAws.S3.Crypto","doc":"First, make sure you have the id for your master key (should be of the form of a UUID, like `123e4567-e89b-12d3-a456-426655440000`) and the\nbucket you're using already set up.  You should be able to make requests using `ExAws` (see\n[the ExAws docs](https://hexdocs.pm/ex_aws/ExAws.html#module-aws-key-configuration) for configuration instructions).\n\nTo encrypt and upload an object, it's easy as pie.\n\n    bucket = \"my-awesome-bucket\"\n    key_id = \"123e4567-e89b-12d3-a456-426655440000\"\n    contents = \"this is some special text that should be secret\"\n\n    # Encrypt, then upload object\n    request = ExAws.S3.put_object(bucket, \"secret.txt.enc\", contents)\n    {:ok, encrypted_request} = ExAws.S3.Crypto.encrypt(request, key_id)\n    ExAws.request(encrypted_request)\n\n    # Or, use this shorter version of above\n    ExAws.S3.Crypto.put_encrypted_object(bucket, \"secret.txt.enc\", contents, key_id)\n\nDecrypting is easy too, and doesn't even require knowing the original key id.\n\n    # get encrypted object, then decrypt\n    {:ok, encrypted} = ExAws.S3.get_object(bucket, \"secret.txt.enc\") |> ExAws.request\n    {:ok, decrypted} = ExAws.S3.Crypto.decrypt(encrypted)\n    IO.puts decrypted.body\n\n    # Or, use this shorter version of above\n    {:ok, decrypted} = ExAws.S3.Crypto.get_encrypted_object(bucket, \"secret.txt.enc\")\n    IO.puts decrypted.body","ref":"ExAws.S3.Crypto.html#module-examples"},{"type":"function","title":"ExAws.S3.Crypto.decrypt/1","doc":"Take the result of a `ExAws.S3.get_object/3` and replace the body with the decrypted value.\n\nFor example:\n\n    bucket = \"my-awesome-bucket\"\n    key_id = \"123e4567-e89b-12d3-a456-426655440000\"\n\n    # get encrypted object, then decrypt\n    {:ok, encrypted} = ExAws.S3.get_object(bucket, \"secret.txt.enc\") |> ExAws.request\n    {:ok, decrypted} = ExAws.S3.Crypto.decrypt(encrypted)\n    IO.puts decrypted.body","ref":"ExAws.S3.Crypto.html#decrypt/1"},{"type":"function","title":"ExAws.S3.Crypto.encrypt/3","doc":"Modify a `ExAws.Operation.S3` put operation by encrypting the body with a key generated\nfrom KMS using the given master key_id.\n\nFor example:\n\n    bucket = \"my-awesome-bucket\"\n    key_id = \"123e4567-e89b-12d3-a456-426655440000\"\n    contents = \"this is some special text that should be secret\"\n\n    # Encrypt, then upload object\n    request = ExAws.S3.put_object(bucket, \"secret.txt.enc\", contents)\n    {:ok, encrypted_request} = ExAws.S3.Crypto.encrypt(request, key_id)\n    ExAws.request(encrypted_request)","ref":"ExAws.S3.Crypto.html#encrypt/3"},{"type":"type","title":"ExAws.S3.Crypto.encrypt_opts/0","doc":"","ref":"ExAws.S3.Crypto.html#t:encrypt_opts/0"},{"type":"function","title":"ExAws.S3.Crypto.get_encrypted_object/3","doc":"Get an object from a bucket and then decrypt the body.  This merely wraps sending a `ExAws.S3.get_object/3` request and then calling `decrypt/1` with\nthe results.\n\nFor example:\n\n    {:ok, decrypted} = ExAws.S3.Crypto.get_encrypted_object(\"my-awesome-bucket\", \"secret.txt.enc\")\n    IO.puts decrypted.body","ref":"ExAws.S3.Crypto.html#get_encrypted_object/3"},{"type":"function","title":"ExAws.S3.Crypto.put_encrypted_object/5","doc":"Encrypt and then create an object within a bucket.  This merely wraps creating a `ExAws.Operation.S3` request, calling `encrypt/3`, and uploading to S3\nvia a call to `ExAws.request/1`.\n\nFor example:\n\n    bucket = \"my-awesome-bucket\"\n    key_id = \"123e4567-e89b-12d3-a456-426655440000\"\n    contents = \"this is some special text that should be secret\"\n\n    ExAws.S3.Crypto.put_encrypted_object(bucket, \"secret.txt.enc\", contents, key_id)","ref":"ExAws.S3.Crypto.html#put_encrypted_object/5"},{"type":"type","title":"ExAws.S3.Crypto.supported_cipher/0","doc":"","ref":"ExAws.S3.Crypto.html#t:supported_cipher/0"},{"type":"function","title":"ExAws.S3.Crypto.valid_length?/1","doc":"Determine if the length of a decrypted response is what was expected based on file metadata.\n\nThe first argument should be the result of a call to `decrypt/1` or `get_encrypted_object/3`.","ref":"ExAws.S3.Crypto.html#valid_length?/1"},{"type":"module","title":"ExAws.S3.Crypto.AESGCMCipher","doc":"This module wraps the logic necessary to encrypt / decrypt using [AES](https://en.wikipedia.org/wiki/Advanced_Encryption_Standard)\n[GCM](https://en.wikipedia.org/wiki/Galois/Counter_Mode).\n\nSee the Erlang docs for [crypto_one_time_aead](https://erlang.org/doc/man/crypto.html#crypto_one_time_aead-7) for more info.","ref":"ExAws.S3.Crypto.AESGCMCipher.html"},{"type":"function","title":"ExAws.S3.Crypto.AESGCMCipher.decrypt/3","doc":"Decrypt the given contents with the supplied key and initialization vector.","ref":"ExAws.S3.Crypto.AESGCMCipher.html#decrypt/3"},{"type":"function","title":"ExAws.S3.Crypto.AESGCMCipher.encrypt/2","doc":"Encrypt the given contents with the supplied key.","ref":"ExAws.S3.Crypto.AESGCMCipher.html#encrypt/2"},{"type":"module","title":"ExAws.S3.Crypto.KMSWrapper","doc":"Utility module to wrap calls to `ExAws.KMS` to generate / decrypt [data keys](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#data-keys).","ref":"ExAws.S3.Crypto.KMSWrapper.html"},{"type":"function","title":"ExAws.S3.Crypto.KMSWrapper.decrypt_key/2","doc":"Decrypt an encrypted [data key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#data-keys).\n\nThe context is an [encryption context](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context)\nthat should generally just be a map of `%{\"kms_cmk_id\" => key_id}` for the master key_id used in the initial generation.","ref":"ExAws.S3.Crypto.KMSWrapper.html#decrypt_key/2"},{"type":"function","title":"ExAws.S3.Crypto.KMSWrapper.generate_data_key/1","doc":"Generate a [data key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#data-keys) for the master key with the given id.","ref":"ExAws.S3.Crypto.KMSWrapper.html#generate_data_key/1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}